local PetBattleTeams = LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local Config = PetBattleTeams:NewModule("Config","AceConsole-3.0")
local TeamManager = PetBattleTeams:GetModule("TeamManager")
local GUI = PetBattleTeams:GetModule("GUI")

local options = {
    name = "PetBattle Teams",
    handler = self,
    type = 'group',
    args = {
			TeamFrameHeading = {
				order = 0,
				name = "Teams and Pets",
				width = "double",
				type = "header",
			},
			showXpInLevel = {
				order = 1,
				name = "Display pets xp as part of the pets level",
				width = "double",
				type = "toggle",
				set = function(info,val) 
					TeamManager:SetShowXpInLevel(val)
				end,
				get = function(info) return TeamManager:GetShowXpInLevel() end
			},
			showXpInHealth = {
				order = 2,
				name = "Display pets xp instead of the health bar ",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetShowXpInHealthBar(val)
				end,
				get = function(info) return TeamManager:GetShowXpInHealthBar() end
			},
			ShowTeamName = {
				order = 3,
				name = "Display team name above the team",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetShowTeamName(val)
				end,
				get = function(info) return TeamManager:GetShowTeamName()  end
			},
			MainFrameHeading = {
				order = 50,
				name = "Main",
				width = "double",
				type = "header",
				
			},
			AttachToPetJournal = {
				order = 51,
				name = "Attach PetBattle Teams to Pet Journal",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					GUI:SetAttached(val)
				end,
				get = function(info) return GUI:GetAttached() end
			},
			HideInCombat = {
				order = 52,
				name = "Hide PetBattle Teams while in combat or in a pet battle",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					GUI:SetHideInCombat(val)
				end,
				get = function(info) return GUI:GetHideInCombat() end
			},
			LockPosition = {
				order = 52,
				name = "Lock PetBattle Teams Position",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					GUI:SetLocked(val)
				end,
				get = function(info) return GUI:GetLocked() end
			},
			TeamFunctionsHeading = {
				order = 100,
				name = "Team Management",
				width = "double",
				type = "header",
				
			},
			SaveTeams = {
				order = 101,
				name = "Automatically Save Teams",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetAutomaticallySaveTeams(val)
				end,
				get = function(info) return TeamManager:GetAutomaticallySaveTeams() end
			},
			
			UnlockTeams = {
				order = 103,
				name = "Unlock all existing teams",
				width = "double",
				type = "execute",
				func = function() 
					TeamManager:UnlockAllTeams()
				end,
				
			},
			LockAllTeams = {
				order = 103,
				name = "Lock all existing teams",
				width = "double",
				type = "execute",
				func = function() 
					for i=1,TeamManager:GetNumTeams() do
						TeamManager:LockTeam(i,true)
					end
					print("PetBattle Teams: All existing teams locked")
				end,
				
			},
			ResetTeams = {
				order = 110,
				name = "Delete all teams",
				type = "execute",
				width = "double",
				func = function() 
					TeamManager:ResetTeams()
				end,
			},
			
			ResetUI = {
				order = 120,
				name = "Reset UI",
				type = "execute",
				width = "double",
				func = function() 
					GUI:ResetUI()
					TeamManager:ResetUI()
				end,
			},
		},
}

function Config:OnInitialize()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("PetBattleTeams", options,"/pbt")
    LibStub("AceConfigDialog-3.0"):AddToBlizOptions("PetBattleTeams","PetBattle Teams")
end


